## Purpose
You may find that you need to install an XFCE desktop environment or something into Fedora Server, if this is the case, for installing something like Rustdesk remote access, you can follow the steps below.

### Install & Configure XFCE
We need to install XFCE and configure it to be the default environment when the server turns on.
```sh
sudo dnf install @xfce-desktop-environment -y
sudo systemctl set-default graphical.target
sudo reboot
```

#### Install Rustdesk:
We need to install Rustdesk into the server.
```sh
curl -L -o /tmp/rustdesk_installer.rpm https://github.com/rustdesk/rustdesk/releases/download/1.4.0/rustdesk-1.4.0-0.x86_64.rpm
cd /tmp
sudo yum install rustdesk_installer.rpm -y
```

!!! info "Configure Rustdesk"
    You need to use a tool like "MobaXTerm" or "PuTTy" to leverage X11-Forwarding to allow you to run `rustdesk` in a GUI on your local workstation.  From there, you need to configure the relay server information (if you are using a self-hosted Relay).  This is also where you would set up a permanent password to the server and document the device ID number.

    Be sure to check the box for "**Enable remote configuration modification**" when setting up Rustdesk.

### Configure Automatic Login
For Rustdesk specifically, we have to configure XFCE to automatically login via SDDM then immediately lock the computer once it's logged in, so the XFCE session is running, allowing Rustdesk to connect to it.

**Create SDDM Config File**:
```sh
sudo mkdir -p /etc/sddm.conf.d/
sudo nano /etc/sddm.conf.d/autologin.conf
```

```ini title="/etc/sddm.conf.d/autologin.conf"
[Autologin]
User=nicole
Session=xfce.desktop
```

!!! note "Determining Session Strings"
    If you're unsure of the correct session string, check what's available by typing `ls /usr/share/xsessions/`.  You will be looking for something like `xfce.desktop`

### Configure Lock on Initial Login
At this point, its not the most secure thing to just leave a server logged-in upon boot, so the following steps will instantly lock the server after logging in, allowing the XFCE session to persist so Rustdesk can attach to it for remote management of the server.

!!! warning "Not Functional Yet"
    I have tried implementing the below, but it seems to just ignore it and stay logged-in without locking the device.  This needs to be troubleshot further.

```sh
mkdir -p ~/.config/autostart
nano ~/.config/autostart/xfce-lock.desktop
```

```ini title="~/.config/autostart/xfce-lock.desktop"
[Desktop Entry]
Type=Application
Exec=xfce4-screensaver-command -l
Hidden=false
NoDisplay=false
X-GNOME-Autostart-enabled=true
Name=Auto Lock
Comment=Lock the screen on login
```

Lastly, test that everything is working by rebooting the server.
```sh
sudo reboot
```